===============================================================================
=    W i t a j   w   t u t o r i a l u   V I M - a      -    Wersja  1.7.     =
===============================================================================

     Vim to potny edytor, ktry posiada wiele polece, zbyt duo, by
     wyjani je wszystkie w tym tutorialu. Ten przewodnik ma nauczy
     Ci posugiwa si wystarczajco wieloma komendami, by mg atwo
     uywa Vima jako edytora oglnego przeznaczenia.

     Czas potrzebny na ukoczenie tutoriala to 25 do 30 minut i zaley
     od tego jak wiele czasu spdzisz na eksperymentowaniu.

	 UWAGA:
	 Polecenia wykonywane w czasie lekcji zmodyfikuj tekst. Zrb
	 wczeniej kopi tego pliku do wicze (jeli zacze komend
	 "vimtutor", to ju pracujesz na kopii).

	 Pamitaj, e przewodnik ten zosta zaprojektowany do nauki poprzez
	 wiczenia. Oznacza to, e musisz wykonywa polecenia, by nauczy si ich
	 prawidowo. Jeli bdziesz jedynie czyta tekst, szybko zapomnisz wiele
	 polece!

     Teraz upewnij si, e nie masz wcinitego Caps Locka i wciskaj  j
     tak dugo dopki Lekcja 1.1. nie wypeni cakowicie ekranu.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 1.1.: PORUSZANIE SI KURSOREM

       ** By wykona ruch kursorem, wcinij h, j, k, l jak pokazano. **

	       ^
	       k		      Wskazwka:  h jest po lewej
	  < h	  l >				  l jest po prawej
	       j				  j wyglda jak strzaka w d
	       v
  1. Poruszaj kursorem dopki nie bdziesz pewien, e pamitasz polecenia.

  2. Trzymaj  j  tak dugo a bdzie si powtarza.
     Teraz wiesz jak doj do nastpnej lekcji.

  3. Uywajc strzaki w d przejd do nastpnej lekcji.

Uwaga: Jeli nie jeste pewien czego co wpisae, wcinij <ESC>, by wrci do
       trybu Normal. Wtedy powtrz polecenie.

Uwaga: Klawisze kursora take powinny dziaa, ale uywajc  hjkl  bdziesz
       w stanie porusza si o wiele szybciej, jak si tylko przyzwyczaisz.
       Naprawd!

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 1.2.: WYCHODZENIE Z VIM-a

 !! UWAGA: Przed wykonaniem jakiegokolwiek polecenia przeczytaj ca lekcj !!

  1. Wcinij <ESC> (aby upewni si, e jeste w trybie Normal).
  2. Wpisz:			:q!<ENTER>.
     To spowoduje wyjcie z edytora PORZUCAJC wszelkie zmiany, jakie
     zdye zrobi. Jeli chcesz zapamita zmiany i wyj,
     wpisz:			:wq<ENTER>

  3. Kiedy widzisz znak zachty powoki wpisz komend, eby wrci
     do tutoriala. Czyli:	vimtutor<ENTER>

  4. Jeli chcesz zapamita polecenia, wykonaj kroki 1. do 3., aby
     wyj i wrci do edytora.

UWAGA: :q!<ENTER> porzuca wszelkie zmiany jakie zrobie. W nastpnych
       lekcjach dowiesz si jak je zapamitywa.

  5. Przenie kursor do lekcji 1.3.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		 Lekcja 1.3.: EDYCJA TEKSTU - KASOWANIE

	    ** Wcinij  x  aby usun znak pod kursorem. **

  1. Przenie kursor do linii poniej oznaczonej --->.

  2. By poprawi bdy, naprowad kursor na znak do usunicia.

  3. Wcinij  x  aby usun niechciany znak.

  4. Powtarzaj kroki 2. do 4. dopki zdanie nie jest poprawne.

---> Kkrowa prrzeskoczya prrzez ksiiycc.

  5. Teraz, kiedy zdanie jest poprawione, przejd do Lekcji 1.4.

UWAGA: Ucz si przez wiczenie, nie wkuwanie.





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	   Lekcja 1.4.: EDYCJA TEKSTU - INSERT (wprowadzanie)


		  ** Wcinij  i  aby wstawi tekst. **

  1. Przenie kursor do pierwszej linii poniej oznaczonej --->.

  2. Aby poprawi pierwszy wiersz, ustaw kursor na pierwszym znaku PO tym,
     gdzie tekst ma by wstawiony.

  3. Wcinij  i  a nastpnie wpisz konieczne poprawki.

  4. Po poprawieniu bdu wcinij <ESC>, by wrci do trybu Normal.
     Powtarzaj kroki 2. do 4., aby poprawi cae zdanie.

---> W tej brkje troch .
---> W tej linii brakuje troch tekstu.

  5. Kiedy czujesz si swobodnie wstawiajc tekst, przejd do
     podsumowania poniej.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	   Lekcja 1.5.: EDYCJA TEKSTU - APPENDING (dodawanie)


		   ** Wcinij  A  by doda tekst. **

  1. Przenie kursor do pierwszej linii poniej oznaczonej --->.
     Nie ma znaczenia, ktry to bdzie znak.

  2. Wcinij  A  i wpisz odpowiednie dodatki.

  3. Kiedy tekst zosta dodany, wcinij <ESC> i wr do trybu Normalnego.

  4. Przenie kursor do drugiej linii oznaczonej ---> i powtrz kroki 2. i 3.,
     aby poprawi zdanie.

---> Brakuje tu tro
     Brakuje tu troch tekstu.
---> Tu te troch bra
     Tu te troch brakuje.

  5. Kiedy ju utrwalie wiczenie, przejd do lekcji 1.6.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			  Lekcja 1.6.: EDYCJA PLIKU

		  ** Uyj  :wq  aby zapisa plik i wyj. **

   !! UWAGA: zanim wykonasz jakiekolwiek polecenia przeczytaj ca lekcj !!

  1. Zakocz tutorial tak jak w lekcji 1.2.:  :q!
     lub, jeli masz dostp do innego terminala, wykonaj kolejne kroki tam.

  2. W powoce wydaj polecenie:  vim tutor<ENTER>
     "vim" jest poleceniem uruchamiajcym edytor Vim. 'tutor' to nazwa pliku,
     jaki chcesz edytowa. Uyj pliku, ktry moe zosta zmieniony.

  3. Dodaj i usu tekst tak, jak si nauczye w poprzednich lekcjach.

  4. Zapisz plik ze zmianami i opu Vima:  :wq<ENTER>

  5. Jeli zakoczye vimtutor w kroku 1., uruchom go ponownie i przejd
     do podsumowania poniej.

  6. Po przeczytaniu wszystkich krokw i ich zrozumieniu: wykonaj je.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 1. PODSUMOWANIE

  1. Poruszasz kursorem uywajc "strzaek" i klawiszy  hjkl .
       h (w lewo)	 j (w d)	 k (do gry)		l (w prawo)

  2. By wej do Vima, (z powoki) wpisz:
			    vim NAZWA_PLIKU<ENTER>

  3. By wyj z Vima, wpisz:
			    <ESC> :q!<ENTER>  by usun wszystkie zmiany.
	     LUB:	    <ESC> :wq<ENTER>  by zmiany zachowa.

  4. By usun znak pod kursorem, wcinij:  x

  5. By wstawi tekst przed kursorem lub doda:
	i   wpisz tekst   <ESC>         wstawi przed kursorem
	A   wpisz tekst   <ESC>         doda na kocu linii

UWAGA: Wcinicie <ESC> przeniesie Ci z powrotem do trybu Normal
       lub odwoa niechciane lub czciowo wprowadzone polecenia.

Teraz moemy kontynuowa i przej do Lekcji 2.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 2.1.: POLECENIE DELETE (usuwanie)


		      ** Wpisz  dw  by usun wyraz. **

  1. Wcinij  <ESC>, by upewni si, e jeste w trybie Normal.

  2. Przenie kursor do linii poniej oznaczonej --->.

  3. Przesu kursor na pocztek wyrazu, ktry chcesz usun.

  4. Wpisz   dw   by usun wyraz.

  UWAGA: Litera  d  pojawi si na dole ekranu. Vim czeka na wpisanie  w .
	 Jeli zobaczysz inny znak, oznacza to, e wpisae co le; wcinij
	 <ESC> i zacznij od pocztku.

---> Jest tu par papier wyrazw, ktre kamie nie nale do noyce tego zdania.

  5. Powtarzaj kroki 3. i 4. dopki zdanie nie bdzie poprawne, potem
  przejd do Lekcji 2.2.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 2.2.: WICEJ POLECE USUWAJCYCH


	      ** Wpisz	d$  aby usun tekst do koca linii. **

  1. Wcinij  <ESC>  aby si upewni, e jeste w trybie Normal.

  2. Przenie kursor do linii poniej oznaczonej --->.

  3. Przenie kursor do koca poprawnego zdania (PO pierwszej  . ).

  4. Wpisz  d$  aby usun reszt linii.

---> Kto wpisa koniec tego zdania dwukrotnie. zdania dwukrotnie.


  5. Przejd do Lekcji 2.3., by zrozumie co si stao.





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 2.3.: O OPERATORACH I RUCHACH


  Wiele polece zmieniajcych tekst jest zoonych z operatora i ruchu.
  Format dla polecenia usuwajcego z operatorem  d  jest nastpujcy:

	    d  ruch

  gdzie:
   d      - operator usuwania.
   ruch   - na czym polecenie bdzie wykonywane (lista poniej).

  Krtka lista ruchw:
    w - do pocztku nastpnego wyrazu WYCZAJC pierwszy znak.
    e - do koca biecego wyrazu, WCZAJC ostatni znak.
    $ - do koca linii, WCZAJC ostatni znak.

W ten sposb wpisanie  de  usunie znaki od kursora do koca wyrazu.

UWAGA: Wpisanie tylko ruchu w trybie Normal bez operatora przeniesie kursor
       tak, jak to okrelono.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 2.4.: UYCIE MNONIKA DLA RUCHU


   ** Wpisanie liczby przed ruchem powtarza ruch odpowiedni ilo razy. **

  1. Przenie kursor na pocztek linii poniej zaznaczonej --->.

  2. Wpisz  2w  aby przenie kursor o dwa wyrazy do przodu.

  3. Wpisz  3e  aby przenie kursor do koca trzeciego wyrazu w przd.

  4. Wpisz  0  (zero), aby przenie kursor na pocztek linii.

  5. Powtrz kroki 2. i 3. z innymi liczbami.


 ---> To jest zwyky wiersz z wyrazami, po ktrych moesz si porusza.

  6. Przejd do lekcji 2.5.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		Lekcja 2.5.: UYCIE MNONIKA, BY WICEJ USUN


    ** Wpisanie liczby z operatorem powtarza go odpowiedni ilo razy. **

  W wyej wspomnianej kombinacji operatora usuwania i ruchu podaj mnonik
  przed ruchem, by wicej usun:
	d  liczba  ruch

  1. Przenie kursor do pierwszego wyrazu KAPITALIKAMI w linii zaznaczonej --->.

  2. Wpisz  2dw  aby usun dwa wyrazy KAPITALIKAMI.

  3. Powtarzaj kroki 1. i 2. z innymi mnonikami, aby usun kolejne wyrazy
     KAPITALIKAMI jednym poleceniem

---> ta ASD WE linia QWE ASDF ZXCV FG wyrazw zostaa ERT FGH CF oczyszczona.

UWAGA:  Mnonik pomidzy operatorem  d  i ruchem dziaa podobnie do ruchu bez
        operatora.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 2.6.: OPEROWANIE NA LINIACH


		   ** Wpisz  dd  aby usun ca lini. **

  Z powodu czstoci usuwania caych linii, projektanci Vi zdecydowali, e
  bdzie atwiej wpisa dwa razy  d  aby usun lini.

  1. Przenie kursor do drugiego zdania z wierszyka poniej.
  2. Wpisz  dd  aby usun wiersz.
  3. Teraz przenie si do czwartego wiersza.
  4. Wpisz  2dd  aby usun dwa wiersze.

--->  1)  Re s czerwone,
--->  2)  Boto jest fajne,
--->  3)  Fioki s niebieskie,
--->  4)  Mam samochd,
--->  5)  Zegar podaje czas,
--->  6)  Cukier jest sodki,
--->  7)  I ty te.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 2.7.: POLECENIE UNDO (cofnij)


	  ** Wcinij  u  aby cofn skutki ostatniego polecenia.
		 U za, by cofn skutki dla caej linii. **

  1. Przenie kursor do zdania poniej oznaczonego ---> i umie go na
     pierwszym bdzie.
  2. Wpisz  x  aby usun pierwszy niechciany znak.
  3. Teraz wcinij  u  aby cofn skutki ostatniego polecenia.
  4. Tym razem popraw wszystkie bdy w linii uywajc polecenia  x .
  5. Teraz wcinij wielkie  U  aby przywrci lini do oryginalnego stanu.
  6. Teraz wcinij  u  kilka razy, by cofn  U  i poprzednie polecenia.
  7. Teraz wpisz CTRL-R (trzymaj rwnoczenie wcinite klawisze CTRL i R)
     kilka razy, by cofn cofnicia.

---> Poopraw bdyyy w teej liniii i zaamiie je prrzez coofnij.

  8. To s bardzo poyteczne polecenia.

     Przejd teraz do podsumowania Lekcji 2.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 2. PODSUMOWANIE


  1. By usun znaki od kursora do nastpnego wyrazu, wpisz:   dw
  2. By usun znaki od kursora do koca linii, wpisz:    d$
  3. By usun ca lini:    dd
  4. By powtrzy ruch, poprzed go liczb:    2w
  5. Format polecenia zmiany to:
                operator  [liczba]  ruch
  gdzie:
   operator  - to, co trzeba zrobi (np.  d  dla usuwania)
   [liczba]  - opcjonalne, ile razy powtrzy ruch
   ruch      - przenosi nad tekstem do operowania, takim jak  w (wyraz),
	       $  (do koca linii) etc.

  6. By przej do pocztku linii, uyj zera:  0
  7. By cofn poprzednie polecenie, wpisz:	  u  (mae u)
     By cofn wszystkie zmiany w linii, wpisz:	  U  (wielkie U)
     By cofn cofnicie, wpisz:			  CTRL-R



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 3.1.: POLECENIE PUT (wstaw)


	  ** Wpisz  p  by wstawi ostatnie usunicia za kursorem. **

  1. Przenie kursor do pierwszej linii ---> poniej.

  2. Wpisz  dd  aby usun lini i przechowa j w rejestrze Vima.

  3. Przenie kursor do linii c), POWYEJ tej, gdzie usunita linia powinna
     si znajdowa.

  4. Wcinij  p  by wstawi lini poniej kursora.

  5. Powtarzaj kroki 2. do 4. a znajd si w odpowiednim porzdku.

---> d) Jak dwa anioki.
---> b) Na dole fioki,
---> c) A my si kochamy,
---> a) Na grze re,


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 3.2.: POLECENIE REPLACE (zastp)


	   ** Wpisz  rx  aby zastpi znak pod kursorem na  x . **

  1. Przenie kursor do pierwszej linii poniej oznaczonej --->

  2. Ustaw kursor na pierwszym bdzie.

  3. Wpisz  r  a potem znak jaki powinien go zastpi.

  4. Powtarzaj kroki 2. i 3. dopki pierwsza linia nie bdzie taka, jak druga.

--->  Kjedy ten wiersz bi wstkiwany, kto wcizn per zych klawirzy!
--->  Kiedy ten wiersz by wstukiwany, kto wcisn par zych klawiszy!

  5. Teraz czas na Lekcj 3.3.


UWAGA: Pamitaj, by uczy si wiczc, a nie pamiciowo.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 3.3.: OPERATOR CHANGE (zmie)

		 ** By zmieni do koca wyrazu, wpisz  ce . **

  1. Przenie kursor do pierwszej linii poniej oznaczonej --->.

  2. Umie kursor na  u  w lunos.

  3. Wpisz  ce  i popraw wyraz (w tym wypadku wstaw  inia ).

  4. Wcinij <ESC> i przejd do nastpnej planowanej zmiany.

  5. Powtarzaj kroki 3. i 4. dopki pierwsze zdanie nie bdzie takie same,
     jak drugie.

---> Ta lunos ma pire sw, ktre tina zbnic uifajonc pcmazu zmie.
---> Ta linia ma par sw, ktre trzeba zmieni uywajc polecenia zmie.

  Zauwa, e  ce  nie tylko zamienia wyraz, ale take zmienia tryb na
  Insert (wprowadzanie).


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 3.4.: WICEJ ZMIAN UYWAJC c


	** Polecenie change uywa takich samych ruchw, jak delete. **

  1. Operator change dziaa tak samo, jak delete. Format wyglda tak:

	    c   [liczba]   ruch

  2. Ruchy s take takie same, np.:  w  (wyraz),  $  (koniec linii) etc.

  3. Przenie si do pierwszej linii poniej oznaczonej --->

  4. Ustaw kursor na pierwszym bdzie.

  5. Wpisz  c$ , popraw koniec wiersza i wcinij <ESC>.

---> Koniec tego wiersza musi by poprawiony, aby wyglda tak, jak drugi.
---> Koniec tego wiersza musi by poprawiony uywajc polecenia  c$ .

UWAGA:  Moesz uywa <BS> aby poprawia bdy w czasie pisania.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 3. PODSUMOWANIE


  1. Aby wstawi tekst, ktry zosta wczeniej usunity wcinij  p . To
     polecenie wstawia skasowany tekst PO kursorze (jeli caa linia
     zostaa usunita, zostanie ona umieszczona w linii poniej kursora).

  2. By zamieni znak pod kursorem, wcinij  r  a potem znak, ktry ma zastpi
     oryginalny.

  3. Operator change pozwala Ci na zastpienie od kursora do miejsca, gdzie
     zabraby Ci ruch. Np. wpisz  ce  aby zamieni tekst od kursora do koca
     wyrazu,  c$  aby zmieni tekst do koca linii.

  4. Format do polecenia change (zmie):

	c   [liczba]   obiekt

     Teraz przejd do nastpnej lekcji.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	       Lekcja 4.1.: POOENIE KURSORA ORAZ STATUS PLIKU

       ** Nacinij CTRL-G aby zobaczy swoje pooenie w pliku i status
	  pliku. Nacinij  G  aby przej do linii w pliku. **

  UWAGA: Przeczytaj ca lekcj zanim wykonasz jakie polecenia!!!

  1. Przytrzymaj klawisz CTRL i wcinij  g . Uywamy notacji CTRL-G.
     Na dole strony pojawi si pasek statusu z nazw pliku i pozycj w pliku.
     Zapamitaj numer linii dla potrzeb kroku 3.

UWAGA: Moesz te zobaczy pozycj kursora w prawym, dolnym rogu ekranu.
       Dzieje si tak kiedy ustawiona jest opcja 'ruler' (wicej w lekcji 6.).

  2. Wcinij G aby przej na koniec pliku.
     Wcinij  gg  aby przej do pocztku pliku.

  3. Wpisz numer linii, w ktrej bye a potem  G . To przeniesie Ci
     z powrotem do linii, w ktrej bye kiedy wcisne CTRL-G.

  4. Jeli czujesz si wystarczajco pewnie, wykonaj kroki 1-3.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 4.2.: POLECENIE SZUKAJ


	     ** Wpisz  /  a nastpnie wyraenie, aby je znale. **

  1. W trybie Normal wpisz  / . Zauwa, e znak ten oraz kursor pojawi
     si na dole ekranu tak samo, jak polecenie  : .

  2. Teraz wpisz  bond<ENTER> .  To jest sowo, ktrego chcesz szuka.

  3. By szuka tej samej frazy ponownie, po prostu wcinij  n .
     Aby szuka tej frazy w przeciwnym, kierunku wcinij  N .

  4. Jeli chcesz szuka frazy do tyu, uyj polecenia  ?  zamiast  / .

  5. Aby wrci gdzie bye, wcinij  CTRL-O. Powtarzaj, by wrci dalej. CTRL-I
     idzie do przodu.

Uwaga:  'bond' to nie jest metoda, by przeliterowa bd; 'bond' to bd.
Uwaga:  Kiedy szukanie osignie koniec pliku, bdzie kontynuowane od pocztku
        o ile opcja 'wrapscan' nie zostaa przestawiona.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		Lekcja 4.3.: W POSZUKIWANIU PARUJCYCH NAWIASW


	       ** Wpisz  %  by znale parujcy ), ], lub } . **

  1. Umie kursor na ktrym z (, [, lub { w linii poniej oznaczonej --->.

  2. Teraz wpisz znak  % .

  3. Kursor powinien si znale na parujcym nawiasie.

  4. Wcinij  %  aby przenie kursor z powrotem do parujcego nawiasu.

  5. Przenie kursor do innego (,),[,],{ lub } i zobacz co robi  % .

---> To ( jest linia testowa z (, [, ] i {, } . ))

Uwaga: Ta funkcja jest bardzo uyteczna w debuggowaniu programu
       z niesparowanymi nawiasami!



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 4.4.: POLECENIE SUBSTITUTE (zamiana)


	 ** Wpisz  :s/stary/nowy/g  aby zamieni 'stary' na 'nowy'. **

  1. Przenie kursor do linii poniej oznaczonej --->.

  2. Wpisz  :s/czaas/czas<ENTER> .  Zauwa, e to polecenie zmienia
     tylko pierwsze wystpienie 'czaas' w linii.

  3. Teraz wpisz  :s/czaas/czas/g  . Dodane  g  oznacza zamian (substytucj)
     globalnie w caej linii.  Zmienia wszystkie wystpienia 'czaas' w linii.

---> Najlepszy czaas na zobaczenie najadniejszych kwiatw to czaas wiosny.

  4. Aby zmieni wszystkie wystpienia acucha znakw pomidzy dwoma liniami,
     wpisz: :#,#s/stare/nowe/g gdzie #,# s numerami linii ograniczajcych
                               region, gdzie ma nastpi zamiana.
     wpisz  :%s/stare/nowe/g   by zmieni wszystkie wystpienia w caym pliku.
     wpisz  :%s/stare/nowe/gc  by zmieni wszystkie wystpienia w caym
                               pliku, proszc o potwierdzenie za kadym razem.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 4. PODSUMOWANIE

  1. CTRL-G   pokae Twoj pozycj w pliku i status pliku.  SHIFT-G przenosi
	      Ci do koca pliku.
     G        przenosi do koca pliku.
     liczba G przenosi do linii [liczba].
     gg       przenosi do pierwszej linii.

  2. Wpisanie  /  a nastpnie acucha znakw szuka acucha DO PRZODU.
     Wpisanie  ?  a nastpnie acucha znakw szuka acucha DO TYU.
     Po wyszukiwaniu wcinij  n  by znale nastpne wystpienie szukanej
     frazy w tym samym kierunku lub  N  by szuka w kierunku przeciwnym.
     CTRL-O przenosi do starszych pozycji, CTRL-I do nowszych.

  3. Wpisanie  %  gdy kursor znajduje si na (,),[,],{, lub } lokalizuje
     parujcy znak.

  4. By zamieni pierwszy stary na nowy w linii, wpisz      :s/stary/nowy
     By zamieni wszystkie stary na nowy w linii, wpisz     :s/stary/nowy/g
     By zamieni frazy pomidzy dwoma liniami # wpisz      :#,#s/stary/nowy/g
     By zamieni wszystkie wystpienia w pliku, wpisz       :%s/stary/nowy/g
     By Vim prosi Ci o potwierdzenie, dodaj 'c'	   :%s/stary/nowy/gc
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		 Lekcja 5.1.: JAK WYKONA POLECENIA ZEWNTRZNE?


	** Wpisz  :!  a nastpnie zewntrzne polecenie, by je wykona. **

  1. Wpisz znajome polecenie  :  by ustawi kursor na dole ekranu. To pozwala
     na wprowadzenie komendy linii polece.

  2. Teraz wstaw  !  (wykrzyknik). To umoliwi Ci wykonanie dowolnego
     zewntrznego polecenia powoki.

  3. Jako przykad wpisz  ls  za  !  a nastpnie wcinij <ENTER>. To polecenie
     pokae spis plikw w Twoim katalogu, tak jakby by przy znaku zachty
     powoki. Moesz te uy  :!dir  jeli  ls  nie dziaa.

Uwaga:  W ten sposb mona wykona wszystkie polecenia powoki.
Uwaga:  Wszystkie polecenia  :  musz by zakoczone <ENTER>.
        Od tego momentu nie zawsze bdziemy o tym wspomina.




~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 5.2.: WICEJ O ZAPISYWANIU PLIKW


	   ** By zachowa zmiany w tekcie, wpisz :w NAZWA_PLIKU . **

  1. Wpisz  :!dir  lub  :!ls  by zobaczy spis plikw w katalogu.
     Ju wiesz, e musisz po tym wcisn <ENTER>.

  2. Wybierz nazw pliku, jaka jeszcze nie istnieje, np. TEST.

  3. Teraz wpisz:   :w TEST   (gdzie TEST jest nazw pliku jak wybrae.)

  4. To polecenie zapamita cay plik (Vim Tutor) pod nazw TEST.
     By to sprawdzi, wpisz  :!dir  lub  :!ls  eby znowu zobaczy list plikw.

Uwaga: Zauwa, e gdyby teraz wyszed z Vima, a nastpnie wszed ponownie
       poleceniem  vim TEST , plik byby dokadn kopi tutoriala, kiedy go
       zapisywae.

  5. Teraz usu plik wpisujc (MS-DOS):		   :!del TEST
                          lub (Unix):              :!rm TEST

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		    Lekcja 5.3.: WYBRANIE TEKSTU DO ZAPISU


	  ** By zachowa cz pliku, wpisz  v ruch :w NAZWA_PLIKU **

  1. Przenie kursor do tego wiersza.

  2. Wcinij  v  i przenie kursor do punktu 5. Zauwa, e tekst zosta
     podwietlony.

  3. Wcinij znak  : . Na dole ekranu pojawi si  :'<,'> .

  4. Wpisz  w TEST , gdzie TEST to nazwa pliku, ktry jeszcze nie istnieje.
     Upewnij si, e widzisz  :'<,'>w TEST zanim wciniesz Enter.

  5. Vim zapisze wybrane linie do pliku TEST. Uyj  :!dir  lub  :!ls , eby to
     zobaczy. Jeszcze go nie usuwaj! Uyjemy go w nastpnej lekcji.

UWAGA: Wcinicie  v  zaczyna tryb Wizualny. Moesz porusza kursorem, by
       zmieni rozmiary zaznaczenia. Moesz te uy operatora, by zrobi co
       z tekstem. Na przykad  d  usuwa tekst.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 5.4.: WSTAWIANIE I CZENIE PLIKW


	    ** By wstawi zawarto pliku, wpisz   :r NAZWA_PLIKU **

  1. Umie kursor tu powyej tej linii.

UWAGA: Po wykonaniu kroku 2. zobaczysz tekst z Lekcji 5.3. Potem przejd
       do DOU, by zobaczy ponownie t lekcj.

  2. Teraz wczytaj plik TEST uywajc polecenia  :r TEST , gdzie TEST
     jest nazw pliku.
     Wczytany plik jest umieszczony poniej linii z kursorem.

  3. By sprawdzi czy plik zosta wczytany, cofnij kursor i zobacz, e
     teraz s dwie kopie Lekcji 5.3., orygina i kopia z pliku.

UWAGA: Moesz te wczyta wyjcie zewntrznego polecenia. Na przykad
       :r !ls  wczytuje wyjcie polecenia ls i umieszcza je pod poniej
       kursora.


~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 5. PODSUMOWANIE


  1.  :!polecenie wykonuje polecenie zewntrzne.

      Uytecznymi przykadami s:

	  :!dir  -  pokazuje spis plikw w katalogu.

	  :!rm NAZWA_PLIKU  -  usuwa plik NAZWA_PLIKU.

  2.  :w NAZWA_PLIKU  zapisuje obecny plik Vima na dysk z nazw NAZWA_PLIKU.

  3.  v ruch :w NAZWA_PLIKU  zapisuje Wizualnie wybrane linie do NAZWA_PLIKU.

  4.  :r NAZWA_PLIKU  wczytuje z dysku plik NAZWA_PLIKU i wstawia go do
      biecego pliku poniej kursora.

  5.  :r !dir  wczytuje wyjcie polecenia dir i umieszcza je poniej kursora.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		      Lekcja 6.1.: POLECENIE OPEN (otwrz)


      ** Wpisz  o  by otworzy lini poniej kursora i przenie si do
	 trybu Insert (wprowadzanie). **

  1. Przenie kursor do linii poniej oznaczonej --->.

  2. Wpisz  o  (mae), by otworzy lini PONIEJ kursora i przenie si
     do trybu Insert (wprowadzanie).

  3. Wpisz troch tekstu i wcinij <ESC> by wyj z trybu Insert (wprowadzanie).

---> Po wciniciu  o  kursor znajdzie si w otwartej linii w trybie Insert.

  4. By otworzy lini POWYEJ kursora, wcinij wielkie  O  zamiast maego
     o . Wyprbuj to na linii poniej.

---> Otwrz lini powyej wciskajc SHIFT-O gdy kursor bdzie na tej linii.



~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		     Lekcja 6.2.: POLECENIE APPEND (dodaj)


		  ** Wpisz  a  by doda tekst ZA kursorem. **

  1. Przenie kursor do pocztku pierwszej linii poniej oznaczonej --->

  2. Wciskaj  e  dopki kursor nie bdzie na kocu li .

  3. Wpisz  a  (mae), aby doda tekst ZA znakiem pod kursorem.

  4. Dokocz wyraz tak, jak w linii poniej. Wcinij <ESC> aby opuci tryb
     Insert.

  5. Uyj  e  by przej do kolejnego niedokoczonego wyrazu i powtarzaj kroki
     3. i 4.

---> Ta li poz Ci wi dodaw teks do ko lin
---> Ta linia pozwoli Ci wiczy dodawanie tekstu do koca linii.

Uwaga:  a ,  i  oraz  A  prowadz do trybu Insert, jedyn rnic jest miejsce,
       gdzie nowe znaki bd dodawane.
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   Lekcja 6.3.: INNA WERSJA REPLACE (zamiana)


	   ** Wpisz wielkie  R  by zamieni wicej ni jeden znak. **

  1. Przenie kursor do pierwszej linii poniej oznaczonej --->. Przenie
     kursor do pierwszego  xxx .

  2. Wcinij  R  i wpisz numer poniej w drugiej linii, tak, e zastpi on
     xxx.

  3. Wcinij <ESC> by opuci tryb Replace. Zauwa, e reszta linii pozostaje
     niezmieniona.

  5. Powtarzaj kroki by wymieni wszystkie xxx.

---> Dodanie 123 do xxx daje xxx.
---> Dodanie 123 do 456 daje 579.

UWAGA: Tryb Replace jest jak tryb Insert, ale kady znak usuwa istniejcy
       znak.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		  Lekcja 6.4.: KOPIOWANIE I WKLEJANIE TEKSTU


       ** uyj operatora  y  aby skopiowa tekst i  p  aby go wklei **

  1. Przejd do linii oznaczonej ---> i umie kursor za "a)".

  2. Wejd w tryb Wizualny  v  i przenie kursor na pocztek "pierwszy".

  3. Wcinij  y  aby kopiowa (yankowa) podwietlony tekst.

  4. Przenie kursor do koca nastpnej linii:  j$

  5. Wcinij  p  aby wklei (wpakowa) tekst.  Dodaj:  a drugi<ESC> .

  6. Uyj trybu Wizualnego, aby wybra " element.", yankuj go  y , przejd do
     koca nastpnej linii  j$  i upakuj tam tekst z  p .

--->  a) to jest pierwszy element.
      b)
Uwaga: moesz uy  y  jako operatora;  yw  kopiuje jeden wyraz.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 Lekcja 6.5.: USTAWIANIE OPCJI


** Ustawianie opcji tak, by szukaj lub substytucja ignoroway wielko liter **

  1. Szukaj 'ignore' wpisujc:    /ignore<ENTER>
     Powtrz szukanie kilka razy naciskajc klawisz  n .

  2. Ustaw opcj 'ic' (Ignore case -- ignoruj wielko liter) poprzez
     wpisanie:		:set ic

  3. Teraz szukaj 'ignore' ponownie wciskajc:  n
     Zauwa, e Ignore i IGNORE take s teraz znalezione.

  4. Ustaw opcje 'hlsearch' i 'incsearch':    :set hls is

  5. Teraz wprowad polecenie szukaj ponownie i zobacz co si zdarzy:
     /ignore<ENTER>

  6. Aby wyczy ignorowanie wielkoci liter:  :set noic

Uwaga: Aby usun podwietlanie dopasowa, wpisz:   :nohlsearch
Uwaga: Aby ignorowa wielko liter dla jednego wyszukiwania: /ignore\c<ENTER>
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			     LEKCJA 6. PODSUMOWANIE


  1. Wpisanie  o  otwiera lini PONIEJ kursora.
     Wpisanie  O  otwiera lini POWYEJ kursora.

  2. Wpisanie  a  wstawia tekst ZA znakiem, na ktrym jest kursor.
     Wpisanie  A  dodaje tekst na kocu linii.

  3. Polecenie  e  przenosi do koca wyrazu.
  4. Operator  y  yankuje (kopiuje) tekst,  p  pakuje (wkleja) go.
  5. Wpisanie wielkiego  R  wprowadza w tryb Replace (zamiana) dopki
     nie zostanie wcinity <ESC>.
  6. Wpisanie ":set xxx" ustawia opcj "xxx". Niektre opcje:
	'ic'  'ignorecase'	ignoruj wielko znakw
	'is'  'incsearch'	poka czciowe dopasowania
	'hls' 'hlsearch'	podwietl wszystkie dopasowania
     Moesz uy zarwno dugiej, jak i krtkiej formy.
  7. Dodaj "no", aby wyczy opcj:   :set noic





~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			 LEKCJA 7.1. JAK UZYSKA POMOC?

		      ** Uycie systemu pomocy on-line **

  Vim posiada bardzo dobry system pomocy on-line. By zacz, sprbuj jednej
  z trzech moliwoci:
	- wcinij klawisz <HELP> (jeli taki masz)
	- wcinij klawisz <F1> (jeli taki masz)
	- wpisz   :help<ENTER>

  Przeczytaj tekst w oknie pomocy, aby dowiedzie si jak dziaa pomoc.
  wpisz CTRL-W CTRL-W    aby przeskoczy z jednego okna do innego
  wpisz :q<ENTER>        aby zamkn okno pomocy.

  Moesz te znale pomoc na kady temat podajc argument polecenia ":help".
  Sprbuj tych (nie zapomnij wcisn <ENTER>):

  :help w
  :help c_CTRL-D
  :help insert-index
  :help user-manual
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
		   LEKCJA 7.2. TWORZENIE SKRYPTU STARTOWEGO

			  ** Wcz moliwoci Vima **

  Vim ma o wiele wicej moliwoci ni Vi, ale wikszo z nich jest domylnie
  wyczona. Jeli chcesz wczy te moliwoci na starcie musisz utworzy
  plik "vimrc".

  1. Pocztek edycji pliku "vimrc" zaley od Twojego systemu:
     :edit ~/.vimrc	     dla Uniksa
     :edit $VIM/_vimrc       dla MS-Windows
  2. Teraz wczytaj przykadowy plik "vimrc":
     :read $VIMRUNTIME/vimrc_example.vim
  3. Zapisz plik:
     :w

  Nastpnym razem, gdy zaczniesz prac w Vimie bdzie on uywa podwietlania
  skadni. Moesz doda wszystkie swoje ulubione ustawienia do tego pliku
  "vimrc".
  Aby uzyska wicej informacji, wpisz     :help vimrc-intro

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			  Lekcja 7.3.: UZUPENIANIE


	      ** Uzupenianie linii polece z CTRL-D i <TAB> **

  1. Upewnij si, e Vim nie jest w trybie kompatybilnoci:   :set nocp

  2. Zerknij, jakie pliki s w biecym katalogu:   :!ls   lub   :!dir

  3. Wpisz pocztek polecenia:   :e

  4. Wcinij  CTRL-D  i Vim pokae list polece, jakie zaczynaj si na "e".

  5. Wcinij  <TAB>  i Vim uzupeni polecenie do ":edit".

  6. Dodaj spacj i zacznij wpisywa nazw istniejcego pliku:   :edit FIL

  7. Wcinij <TAB>. Vim uzupeni nazw (jeli jest niepowtarzalna).

UWAGA: Uzupenianie dziaa dla wielu polece. Sprbuj wcisn CTRL-D i <TAB>.
       Uyteczne zwaszcza przy  :help .
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
			    Lekcja 7. PODSUMOWANIE


  1. Wpisz  :help  albo wcinij <F1> lub <Help> aby otworzy okno pomocy.

  2. Wpisz  :help cmd  aby uzyska pomoc o  cmd .

  3. Wpisz  CTRL-W CTRL-W  aby przeskoczy do innego okna.

  4. Wpisz  :q  aby zamkn okno pomocy.

  5. Utwrz plik startowy vimrc aby zachowa wybrane ustawienia.

  6. Po poleceniu  : , wcinij CTRL-D aby zobaczy moliwe uzupenienia.
     Wcinij <TAB> aby uy jednego z nich.






~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  Tutaj si koczy tutorial Vima. Zosta on pomylany tak, aby da krtki
  przegld jego moliwoci, wystarczajcy by mg go uywa. Jest on
  daleki od kompletnoci, poniewa Vim ma o wiele, wiele wicej polece.

  Dla dalszej nauki rekomendujemy ksik:
	Vim - Vi Improved - autor Steve Oualline
	Wydawca: New Riders
  Pierwsza ksika cakowicie powicona Vimowi. Uyteczna zwaszcza dla
  pocztkujcych. Zawiera wiele przykadw i ilustracji.
  Zobacz http://iccf-holland.org./click5.html

  Starsza pozycja i bardziej o Vi ni o Vimie, ale take warta
  polecenia:
	Learning the Vi Editor - autor Linda Lamb
	Wydawca: O'Reilly & Associates Inc.
  To dobra ksika, by dowiedzie si niemal wszystkiego, co chciaby zrobi
  z Vi. Szsta edycja zawiera te informacje o Vimie.

  Po polsku wydano:
	Edytor vi. Leksykon kieszonkowy - autor Arnold Robbins
	Wydawca: Helion 2001 (O'Reilly).
	ISBN: 83-7197-472-8
	http://helion.pl/ksiazki/vilek.htm
  Jest to ksieczka zawierajca spis polece vi i jego najwaniejszych
  klonw (midzy innymi Vima).

	Edytor vi - autorzy Linda Lamb i Arnold Robbins
	Wydawca: Helion 2001 (O'Reilly) - wg 6. ang. wydania
	ISBN: 83-7197-539-2
	http://helion.pl/ksiazki/viedyt.htm
  Rozszerzona wersja Learning the Vi Editor w polskim tumaczeniu.

  Ten tutorial zosta napisany przez Michaela C. Pierce'a i Roberta K. Ware'a,
  Colorado School of Mines korzystajc z pomocy Charlesa Smitha,
  Colorado State University.
  E-mail: bware@mines.colorado.edu.

  Zmodyfikowane dla Vima przez Brama Moolenaara.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  Przetumaczone przez Mikoaja Machowskiego,
  Sierpie 2001,
  rev. Marzec 2002
  2nd rev. Wrzesie 2004
  3rd rev. Marzec 2006
  4th rev. Grudzie 2008
  Wszelkie uwagi prosz kierowa na: mikmach@wp.pl
